@@ -30,7 +30,7 @@ import ionit_plugin
 try:
     import yaml
 except ImportError:
-    import ruamel.yaml as yaml
+    from ruamel import yaml
 
 
 DEFAULT_CONFIG = "/etc/ionit"
@@ -57,20 +57,9 @@ def load_python_plugin(file_path, current_context):
     dont_write_bytecode = sys.dont_write_bytecode
     sys.dont_write_bytecode = True
     try:
-        if sys.version_info[:2] < (3, 5):
-            # Backwards compatibility for Debian jessie
-            import warnings  # pragma: no cover, pylint: disable=import-outside-toplevel
-
-            with warnings.catch_warnings():  # pragma: no cover
-                warnings.simplefilter("ignore")
-                import imp  # pylint: disable=import-outside-toplevel
-            module = imp.load_source(module_name, file_path)  # pragma: no cover
-            del sys.modules[module_name]  # pragma: no cover
-        else:
-            spec = importlib.util.spec_from_file_location(module_name, file_path)
-            # module_from_spec not available in Python < 3.5.
-            module = importlib.util.module_from_spec(spec)  # pylint: disable=no-member
-            spec.loader.exec_module(module)
+        spec = importlib.util.spec_from_file_location(module_name, file_path)
+        module = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(module)
     except Exception as error:
         logger.exception("Importing Python module '%s' failed:", file_path)
         raise PythonModuleException() from error
@@ -112,7 +101,7 @@ def get_config_files(paths):
     return files
 
 
-def collect_context(paths):
+def collect_context(paths, encoding):
     """Collect context that will be used when rendering the templates"""
     logger = logging.getLogger(SCRIPT_NAME)
     logger.debug("Collecting context...")
@@ -126,13 +115,13 @@ def collect_context(paths):
         try:
             if extension == ".json":
                 logger.info("Reading configuration file '%s'...", file)
-                with open(file) as config_file:
+                with open(file, encoding=encoding) as config_file:
                     file_context = json.load(config_file)
             elif extension == ".py":
                 file_context = load_python_plugin(file, context)
             elif extension == ".yaml":
                 logger.info("Reading configuration file '%s'...", file)
-                with open(file) as config_file:
+                with open(file, encoding=encoding) as config_file:
                     file_context = yaml.load(config_file, Loader=yaml.SafeLoader)
             else:
                 logger.info(
@@ -163,7 +152,7 @@ def collect_context(paths):
     return failures, context
 
 
-def render_templates(template_dir, context, template_extension):
+def render_templates(template_dir, context, template_extension, encoding):
     """
     Search in the template directory for template files and render them with the context
     """
@@ -193,7 +182,7 @@ def render_templates(template_dir, context, template_extension):
             continue
 
         try:
-            with open(rendered_filename, "w") as output_file:
+            with open(rendered_filename, "w", encoding=encoding) as output_file:
                 output_file.write(rendered)
         except OSError as error:
             logger.error("Failed to write rendered template to '%s': %s", rendered_filename, error)
@@ -212,8 +201,8 @@ def main(argv):
         "-c",
         "--config",
         action="append",
-        help="Configuration directory/file containing context for rendering (default: %s)"
-        % (DEFAULT_CONFIG,),
+        help="Configuration directory/file containing context for rendering "
+        f"(default: {DEFAULT_CONFIG})",
     )
     parser.add_argument(
         "-t",
@@ -227,6 +216,11 @@ def main(argv):
         default="jinja",
         help="Extension to look for in template directory (default: %(default)s)",
     )
+    parser.add_argument(
+        "--encoding",
+        default="utf-8",
+        help="Encoding of the configuration files and Jinja templates (default: %(default)s)",
+    )
     parser.add_argument(
         "--debug",
         dest="log_level",
@@ -249,9 +243,9 @@ def main(argv):
     logging.basicConfig(level=args.log_level, format=LOG_FORMAT)
     logger = logging.getLogger(SCRIPT_NAME)
 
-    failures, context = collect_context(args.config)
+    failures, context = collect_context(args.config, args.encoding)
     logger.debug("Context: %s", context)
-    failures += render_templates(args.templates, context, args.template_extension)
+    failures += render_templates(args.templates, context, args.template_extension, args.encoding)
     return failures
 
 
